@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_budgets.paginator import (
     DescribeBudgetsPaginator,
@@ -43,27 +43,27 @@ __all__ = ("BudgetsClient",)
 
 
 class Exceptions:
-    AccessDeniedException: Boto3ClientError
-    ClientError: Boto3ClientError
-    CreationLimitExceededException: Boto3ClientError
-    DuplicateRecordException: Boto3ClientError
-    ExpiredNextTokenException: Boto3ClientError
-    InternalErrorException: Boto3ClientError
-    InvalidNextTokenException: Boto3ClientError
-    InvalidParameterException: Boto3ClientError
-    NotFoundException: Boto3ClientError
+    AccessDeniedException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    CreationLimitExceededException: Type[Boto3ClientError]
+    DuplicateRecordException: Type[Boto3ClientError]
+    ExpiredNextTokenException: Type[Boto3ClientError]
+    InternalErrorException: Type[Boto3ClientError]
+    InvalidNextTokenException: Type[Boto3ClientError]
+    InvalidParameterException: Type[Boto3ClientError]
+    NotFoundException: Type[Boto3ClientError]
 
 
 class BudgetsClient:
     """
-    [Budgets.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client)
+    [Budgets.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.can_paginate)
         """
 
     def create_budget(
@@ -73,7 +73,7 @@ class BudgetsClient:
         NotificationsWithSubscribers: List[NotificationWithSubscribersTypeDef] = None,
     ) -> Dict[str, Any]:
         """
-        [Client.create_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.create_budget)
+        [Client.create_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.create_budget)
         """
 
     def create_notification(
@@ -84,7 +84,7 @@ class BudgetsClient:
         Subscribers: List[SubscriberTypeDef],
     ) -> Dict[str, Any]:
         """
-        [Client.create_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.create_notification)
+        [Client.create_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.create_notification)
         """
 
     def create_subscriber(
@@ -95,19 +95,19 @@ class BudgetsClient:
         Subscriber: SubscriberTypeDef,
     ) -> Dict[str, Any]:
         """
-        [Client.create_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.create_subscriber)
+        [Client.create_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.create_subscriber)
         """
 
     def delete_budget(self, AccountId: str, BudgetName: str) -> Dict[str, Any]:
         """
-        [Client.delete_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.delete_budget)
+        [Client.delete_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.delete_budget)
         """
 
     def delete_notification(
         self, AccountId: str, BudgetName: str, Notification: NotificationTypeDef
     ) -> Dict[str, Any]:
         """
-        [Client.delete_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.delete_notification)
+        [Client.delete_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.delete_notification)
         """
 
     def delete_subscriber(
@@ -118,12 +118,12 @@ class BudgetsClient:
         Subscriber: SubscriberTypeDef,
     ) -> Dict[str, Any]:
         """
-        [Client.delete_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.delete_subscriber)
+        [Client.delete_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.delete_subscriber)
         """
 
     def describe_budget(self, AccountId: str, BudgetName: str) -> DescribeBudgetResponseTypeDef:
         """
-        [Client.describe_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.describe_budget)
+        [Client.describe_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.describe_budget)
         """
 
     def describe_budget_performance_history(
@@ -135,21 +135,21 @@ class BudgetsClient:
         NextToken: str = None,
     ) -> DescribeBudgetPerformanceHistoryResponseTypeDef:
         """
-        [Client.describe_budget_performance_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.describe_budget_performance_history)
+        [Client.describe_budget_performance_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.describe_budget_performance_history)
         """
 
     def describe_budgets(
         self, AccountId: str, MaxResults: int = None, NextToken: str = None
     ) -> DescribeBudgetsResponseTypeDef:
         """
-        [Client.describe_budgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.describe_budgets)
+        [Client.describe_budgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.describe_budgets)
         """
 
     def describe_notifications_for_budget(
         self, AccountId: str, BudgetName: str, MaxResults: int = None, NextToken: str = None
     ) -> DescribeNotificationsForBudgetResponseTypeDef:
         """
-        [Client.describe_notifications_for_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.describe_notifications_for_budget)
+        [Client.describe_notifications_for_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.describe_notifications_for_budget)
         """
 
     def describe_subscribers_for_notification(
@@ -161,7 +161,7 @@ class BudgetsClient:
         NextToken: str = None,
     ) -> DescribeSubscribersForNotificationResponseTypeDef:
         """
-        [Client.describe_subscribers_for_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.describe_subscribers_for_notification)
+        [Client.describe_subscribers_for_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.describe_subscribers_for_notification)
         """
 
     def generate_presigned_url(
@@ -172,12 +172,12 @@ class BudgetsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.generate_presigned_url)
         """
 
     def update_budget(self, AccountId: str, NewBudget: BudgetTypeDef) -> Dict[str, Any]:
         """
-        [Client.update_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.update_budget)
+        [Client.update_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.update_budget)
         """
 
     def update_notification(
@@ -188,7 +188,7 @@ class BudgetsClient:
         NewNotification: NotificationTypeDef,
     ) -> Dict[str, Any]:
         """
-        [Client.update_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.update_notification)
+        [Client.update_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.update_notification)
         """
 
     def update_subscriber(
@@ -200,7 +200,7 @@ class BudgetsClient:
         NewSubscriber: SubscriberTypeDef,
     ) -> Dict[str, Any]:
         """
-        [Client.update_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Client.update_subscriber)
+        [Client.update_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Client.update_subscriber)
         """
 
     @overload
@@ -208,7 +208,7 @@ class BudgetsClient:
         self, operation_name: Literal["describe_budgets"]
     ) -> DescribeBudgetsPaginator:
         """
-        [Paginator.DescribeBudgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
+        [Paginator.DescribeBudgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
         """
 
     @overload
@@ -216,7 +216,7 @@ class BudgetsClient:
         self, operation_name: Literal["describe_notifications_for_budget"]
     ) -> DescribeNotificationsForBudgetPaginator:
         """
-        [Paginator.DescribeNotificationsForBudget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
+        [Paginator.DescribeNotificationsForBudget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
         """
 
     @overload
@@ -224,5 +224,5 @@ class BudgetsClient:
         self, operation_name: Literal["describe_subscribers_for_notification"]
     ) -> DescribeSubscribersForNotificationPaginator:
         """
-        [Paginator.DescribeSubscribersForNotification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
+        [Paginator.DescribeSubscribersForNotification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
         """
